Module socket_path

Module socket_path 

Functions

ensure_socket_dir
Ensure the socket directory exists and return the socket path
lockfile_path
Get the lockfile path corresponding to a socket path
log_file_path
Get the log file path corresponding to a socket path.
socket_path
Generate a deterministic Unix socket path for a workspace and language.