pub fn ensure_socket_dir(
workspace_root: &Path,
language: LanguageId,
) -> Result<PathBuf>Expand description
Ensure the socket directory exists and return the socket path
pub fn ensure_socket_dir(
workspace_root: &Path,
language: LanguageId,
) -> Result<PathBuf>Ensure the socket directory exists and return the socket path