log_file_path

Function log_file_path 

pub fn log_file_path(socket_path: &Path) -> PathBuf
Get the log file path corresponding to a socket path.

The log file lives alongside the socket with a .log extension.