Functions
- ensure_
socket_ dir - Ensure the socket directory exists and return the socket path
- lockfile_
path - Get the lockfile path corresponding to a socket path
- log_
file_ path - Get the log file path corresponding to a socket path.
- socket_
path - Generate a deterministic Unix socket path for a workspace and language.